@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+#
 # Copyright (C) 2012-2013 Steven Myint
 #
 # Permission is hereby granted, free of charge, to any person obtaining
@@ -30,13 +32,15 @@ from __future__ import (absolute_import,
 import io
 import os
 import re
+import signal
+import sys
 import textwrap
 import tokenize
 
 import untokenize
 
 
-__version__ = '0.5.6'
+__version__ = '0.5.7'
 
 
 try:
@@ -89,7 +93,7 @@ def _format_code(source,
 
         if (
             token_type == tokenize.STRING and
-            starts_with_triple(token_string) and
+            token_string.startswith(('"', "'")) and
             (previous_token_type == tokenize.INDENT or only_comments_so_far)
         ):
             if only_comments_so_far:
@@ -117,12 +121,6 @@ def _format_code(source,
     return untokenize.untokenize(modified_tokens)
 
 
-def starts_with_triple(string):
-    """Return True if the string starts with triple single/double quotes."""
-    return (string.strip().startswith('"""') or
-            string.strip().startswith("'''"))
-
-
 def format_docstring(indentation, docstring,
                      summary_wrap_length=0,
                      description_wrap_length=0,
@@ -322,12 +320,22 @@ def _find_shortest_indentation(lines):
 
 def strip_docstring(docstring):
     """Return contents of docstring."""
-    triple = '"""'
-    if docstring.lstrip().startswith("'''"):
-        triple = "'''"
-        assert docstring.rstrip().endswith("'''")
+    docstring = docstring.strip()
 
-    return docstring.split(triple, 1)[1].rsplit(triple, 1)[0].strip()
+    if docstring.startswith("'''"):
+        quote = "'''"
+    elif docstring.startswith('"""'):
+        quote = '"""'
+    elif docstring.startswith("'"):
+        quote = "'"
+    elif docstring.startswith('"'):
+        quote = '"'
+    else:
+        raise ValueError('We only handle strings that start with quotes')
+
+    assert docstring.endswith(quote)
+
+    return docstring.split(quote, 1)[1].rsplit(quote, 1)[0].strip()
 
 
 def normalize_summary(summary):
@@ -391,7 +399,6 @@ def remove_section_header(text):
     'foo\nbar\n'
 
     """
-
     stripped = text.lstrip()
     first = stripped[0]
     if (
@@ -467,8 +474,8 @@ def format_file(filename, args, standard_out):
             standard_out.write('\n'.join(list(diff) + ['']))
 
 
-def main(argv, standard_out, standard_error):
-    """Main entry point."""
+def _main(argv, standard_out, standard_error):
+    """Internal main entry point."""
     import argparse
     parser = argparse.ArgumentParser(description=__doc__, prog='docformatter')
     parser.add_argument('-i', '--in-place', action='store_true',
@@ -512,3 +519,24 @@ def main(argv, standard_out, standard_error):
                 format_file(name, args=args, standard_out=standard_out)
             except IOError as exception:
                 print(unicode(exception), file=standard_error)
+
+
+def main():
+    """Main entry point."""
+    try:
+        # Exit on broken pipe.
+        signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+    except AttributeError:  # pragma: no cover
+        # SIGPIPE is not available on Windows.
+        pass
+
+    try:
+        return _main(sys.argv,
+                     standard_out=sys.stdout,
+                     standard_error=sys.stderr)
+    except KeyboardInterrupt:
+        return 2  # pragma: no cover
+
+
+if __name__ == '__main__':
+    sys.exit(main())
