@@ -2,10 +2,15 @@
 
 """Test suite for docformatter."""
 
-from __future__ import unicode_literals
+from __future__ import (absolute_import,
+                        division,
+                        print_function,
+                        unicode_literals)
 
 import contextlib
 import io
+import os
+import sys
 import tempfile
 
 try:
@@ -17,6 +22,25 @@ except ImportError:
 import docformatter
 
 
+ROOT_DIRECTORY = os.path.abspath(os.path.dirname(__file__))
+
+
+if (
+    'DOCFORMATTER_COVERAGE' in os.environ and
+    int(os.environ['DOCFORMATTER_COVERAGE'])
+):
+    DOCFORMATTER_COMMAND = ['coverage', 'run', '--branch', '--parallel',
+                            '--omit=*/site-packages/*',
+                            os.path.join(ROOT_DIRECTORY, 'docformatter.py')]
+else:
+    # We need to specify the executable to make sure the correct Python
+    # interpreter gets used.
+    DOCFORMATTER_COMMAND = [sys.executable,
+                            os.path.join(
+                                ROOT_DIRECTORY,
+                                'docformatter.py')]  # pragma: no cover
+
+
 class TestUnits(unittest.TestCase):
 
     def test_strip_docstring(self):
@@ -42,6 +66,22 @@ class TestUnits(unittest.TestCase):
     def test_strip_docstring_with_empty_string(self):
         self.assertEqual('', docformatter.strip_docstring('""""""'))
 
+    def test_strip_docstring_with_escaped_quotes(self):
+        self.assertEqual("hello\\'",
+                         docformatter.strip_docstring("'hello\\''"))
+
+    def test_strip_docstring_with_escaped_double_quotes(self):
+        self.assertEqual('hello\\"',
+                         docformatter.strip_docstring('"hello\\""'))
+
+    def test_strip_docstring_with_unhandled(self):
+        with self.assertRaises(ValueError):
+            docformatter.strip_docstring('r"""foo"""')
+
+    def test_strip_docstring_with_unknown(self):
+        with self.assertRaises(ValueError):
+            docformatter.strip_docstring('foo')
+
     def test_format_docstring(self):
         self.assertEqual('"""Hello."""',
                          docformatter.format_docstring('    ', '''
@@ -662,10 +702,34 @@ def foo():
     """
 ''')))
 
-    def test_format_code_with_no_docstring(self):
-        line = '''\
+    def test_format_code_with_double_quote(self):
+        self.assertEqual(
+            '''\
+def foo():
+    """Just a regular string."""
+''',
+            docformatter.format_code(
+                '''\
 def foo():
     "Just a regular string"
+'''))
+
+    def test_format_code_with_single_quote(self):
+        self.assertEqual(
+            '''\
+def foo():
+    """Just a regular string."""
+''',
+            docformatter.format_code(
+                '''\
+def foo():
+    'Just a regular string'
+'''))
+
+    def test_format_code_with_should_skip_nested_triple_quotes(self):
+        line = '''\
+def foo():
+    'Just a """foo""" string'
 '''
         self.assertEqual(line, docformatter.format_code(line))
 
@@ -976,9 +1040,9 @@ def foo():
     """
 ''') as filename:
             output_file = io.StringIO()
-            docformatter.main(argv=['my_fake_program', filename],
-                              standard_out=output_file,
-                              standard_error=None)
+            docformatter._main(argv=['my_fake_program', filename],
+                               standard_out=output_file,
+                               standard_error=None)
             self.assertEqual('''\
 @@ -1,4 +1,2 @@
  def foo():
@@ -990,9 +1054,9 @@ def foo():
 
     def test_diff_with_nonexistent_file(self):
         output_file = io.StringIO()
-        docformatter.main(argv=['my_fake_program', 'nonexistent_file'],
-                          standard_out=output_file,
-                          standard_error=output_file)
+        docformatter._main(argv=['my_fake_program', 'nonexistent_file'],
+                           standard_out=output_file,
+                           standard_error=output_file)
         self.assertIn('no such file', output_file.getvalue().lower())
 
     def test_in_place(self):
@@ -1003,9 +1067,9 @@ def foo():
     """
 ''') as filename:
             output_file = io.StringIO()
-            docformatter.main(argv=['my_fake_program', '--in-place', filename],
-                              standard_out=output_file,
-                              standard_error=None)
+            docformatter._main(argv=['my_fake_program', '--in-place', filename],
+                               standard_out=output_file,
+                               standard_error=None)
             with open(filename) as f:
                 self.assertEqual('''\
 def foo():
@@ -1025,11 +1089,10 @@ def foo():
 ''', directory=inner_directory):
 
                     output_file = io.StringIO()
-                    docformatter.main(argv=['my_fake_program',
-                                            '--recursive',
-                                            directory],
-                                      standard_out=output_file,
-                                      standard_error=None)
+                    docformatter._main(argv=['my_fake_program', '--recursive',
+                                             directory],
+                                       standard_out=output_file,
+                                       standard_error=None)
                     self.assertEqual(
                         '',
                         output_file.getvalue().strip())
@@ -1171,7 +1234,7 @@ def run_docformatter(arguments):
     import sys
     environ['PYTHONPATH'] = os.pathsep.join(sys.path)
     import subprocess
-    return subprocess.Popen([sys.executable, './docformatter'] + arguments,
+    return subprocess.Popen(DOCFORMATTER_COMMAND + arguments,
                             stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE,
                             env=environ)
